<?php

namespace Drupal\project_wiki_entity_content;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\user\EntityOwnerTrait;

/**
 * Provides a list controller for the project wiki entity content entity type.
 */
final class ProjectWikiEntityContentListBuilder extends EntityListBuilder {
  use EntityOwnerTrait;

  /**
   * {@inheritdoc}
   */
  public function buildHeader(): array {
    $header['id'] = $this->t('ID');
    $header['title'] = $this->t('Title');
    $header['category'] = $this->t('Category');
    $header['isDeveloperContent'] = $this->t('Developer Content');
    $header['status'] = $this->t('Status');
    $header['author'] = $this->t('Author');
    $header['createdOn'] = $this->t('Creation Date');
    $header['lastModified'] = $this->t('Last Modified');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity): array {
    /** @var \Drupal\project_wiki_entity_content\Entity\ProjectWikiEntityContent $entity */
    $row['id'] = $entity->id();
    $row['title'] = $entity->toLink();
    $row['category'] = $entity->get('category')->value;
    $row['isDeveloperContent'] = $entity->get('isDeveloperContent')->value ? $this->t('Yes') : $this->t('No');
    $row['status'] = $entity->get('status')->value;
    $row['author'] = $entity->getOwner()->value;
    $row['createdOn'] = $entity->get('created')->value;
    $row['lastModified'] = $entity->get('changed')->value;
    return $row + parent::buildRow($entity);
  }

}
